<?PHP
/*
AINS - Ad Fundum Integrated News Script
Copyright (C) 2001 Johannes Gijsbers

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

For the complete GNU General Public License, read the file LICENSE.

************************
Filename: ains_admin.inc
Version: 0.02b
Written by: Taradino(Taradino@Softhome.net)
Description: Admin functions for use with AINS.
History:
(for details, take a look at CHANGELOG in the documentation dir)
[09-03-2001] 0.00  - Development starts.
[26-03-2001] 0.01a - First test release.
                   - Comments in code.
[08-04-2001] 0.02b - Easier setup.
                   - More comments.
                   - Changed from OOP to normal functions.
                   - Absolute paths.

Goals(Sorted by priority):
- Testing on stability and errors.
************************

*/

include("$ains_path/ains_global.inc");

function admin_form($type = "")
{
    /* This function chooses the admin form to output and outputs the first part of the form.
     * Input:
     *      - $type - the type of form to output. There are five options:
     *          - post
     *          - delete
     *          - modify
     *          - order
     *          - config
     * Output:
     *      - First part of the form.
     *      - None, if step = 2 or the type = createdb.
     * Returns:
     *      - Nothing.
     */
    global $step, $ains_path, $PHP_SELF;
    if(!isset($step)){
        $step = 0;
    }
    if(!connect()){                         // If the config file couldn't be opened...
        $type = "first_setup";              // display the form for the right config.
    }
    if($step != 2 AND $type != "first_setup"){
        $type = strtolower($type);
        ?>
        <form enctype = "multipart/form-data" action = "<?PHP print $PHP_SELF ?>?action=<?PHP print $type ?>"  method = "post">
        <?PHP
        fetch_template($type);                      // Get the template that's needed.
    }
    switch($type){
        case "post":
            post($step);
            break;
        case "delete":
            delete($step);
            break;
        case "modify":
            modify($step);
            break;
        case "order":
            order($step);
            break;
        case "config":
            config($step);
            break;
        case "first_setup":
            first_setup($step);
            break;
    }
    ?>
    </form>
    <?PHP
}

function post($step)
{
    /* This function handles all stuff for posting an article.
     * Input:
     *      - Nothing.
     * Output:
     *      - Form for posting article.(step 0)
     *      - Article posted.(step 2)
     * Returns:
     *      - Nothing.
     */

    global $input_title, $input_subtitle, $input_category, $input_poster, $input_body, $in_template, $SQL;
    switch($step){
        case 0: // Parsing the post form.
            ?>
            <input type = "hidden" name = "step" value = "2">
            <?PHP

            // Parsing the AINS post tags.

            $text_out = $in_template;
            $text_out = str_replace('<!--#input_title#-->', '<input type = "text" name = "input_title" size = "25" maxlength = "128">', $text_out);
            $text_out = str_replace('<!--#input_subtitle#-->', '<input type = "text" name = "input_subtitle" size = "25" maxlength = "255">', $text_out);
            $text_out = str_replace('<!--#input_category#-->', '<input type = "text" name = "input_category" size = "25" maxlength = "64">', $text_out);
            $text_out = str_replace('<!--#input_poster#-->', '<input type = "text" name = "input_poster" size = "25" maxlength = "32">', $text_out);
            $text_out = str_replace('<!--#input_body#-->', '<textarea cols = "85" rows = "10" name = "input_body"></textarea>', $text_out);

            print $text_out;
            break;

        case 2: // Getting the post into the database.

            $tmp_date = Date("Y-m-d H:i:s");

            $next_position = num_of_articles()+1; // New position is the highest position + 1.

            $query = "INSERT INTO ains_articles VALUES ('', '$input_poster', '$tmp_date', ";
            $query .= "'$input_title', '$input_subtitle', '$input_category', '$input_body', '$next_position')";

            $SQL->db_query($query);
            print("Article posted.");
            break;
    }
}

function delete($step)
{
    /* This functions chooses the delete form to output and executes the query to delete.
     * Input:
     *      - Nothing.
     * Output:
     *      - Nothing.(step 0&1)
     *      - Article deleted.(step 2)
     * Returns:
     *      - Nothing.
     */

    global $input_id, $input_position, $SQL;
    switch($step){
        case 0: // Choosing the article to delete.
            ?>
            <input type = "hidden" name = "step" value = "1">
            <?PHP
            $query = "SELECT ID, Title FROM ains_articles ORDER BY Position DESC";
            delete_form($query, $step);
            break;
        case 1: // Confirm deletion.
            ?>
            <input type = "hidden" name = "step" value = "2">
            <input type = "hidden" name = "input_id" value="<?PHP print $input_id ?>">
            <?PHP
            $query = "SELECT ID, Title, Position FROM ains_articles WHERE ID = $input_id";
            delete_form($query, $step);

            break;
        case 2: // Deleting article from the database.
            $query = "DELETE FROM ains_articles WHERE ID = $input_id";
            $SQL->db_query($query);
            $SQL->db_query("UPDATE ains_articles SET Position = Position - 1 WHERE Position > $input_position");
            print("Article deleted.");
            break;
    }
}

function delete_form($query, $step)
{
    /* This function outputs the forms for deleting the article.
     * Input:
     *      - $query - The query to use for the form.
     * Output:
     *      - Article selection form.(step 0)
     *      - Delete confirmation.(step 1)
     * Returns:
     *      - Nothing.
     */

    global $input_id, $in_template, $SQL;
    $SQL->db_query($query);
    $num_results = $SQL->num_results();
    while($SQL->fetch_row()){                       // While there's a new article to be parsed, go on.
        $template_case = 0;
        $current_row = $SQL->Get("current_row");
        if($current_row == 1){                      // If this is the first article. Used for FIRST, LAST etc.
            $template_case = 1;
        }
        if($current_row == $num_results){           // If this is the last article. Used for FIRST, LAST etc.
            $template_case += 2;
        }

        // Parsing the AINS tags.

        $text_out = $in_template;

        
        $text_out = ereg_replace('<!--#FIRST#-->(.*)<!--#/FIRST#-->', ($template_case == 1 || $template_case == 3) ? '\\1' : '', $text_out);
        $text_out = ereg_replace('<!--#NOTFIRST#-->(.*)<!--#\/NOTFIRST#-->', ($template_case == 1 || $template_case == 3) ? '' : '\\1', $text_out);
        $text_out = ereg_replace('<!--#LAST#-->(.*)<!--#/LAST#-->', ($template_case == 2 || $template_case == 3) ? '\\1' : '', $text_out);
        $text_out = ereg_replace('<!--#NOTLAST#-->(.*)<!--#\/NOTLAST#-->', ($template_case == 2 || $template_case == 3) ? '' : '\\1', $text_out);

        $text_out = ereg_replace('<!--#ARTICLES#-->(.*)<!--#/ARTICLES#-->', ($step == 0) ? '\\1' : '', $text_out);
        $text_out = ereg_replace('<!--#CONFIRM#-->(.*)<!--#/CONFIRM#-->', ($step == 1) ? '\\1' : '', $text_out);
		if($step == 1){
			?>
	        <input type = "hidden" name = "input_position" value = "<?PHP print $SQL->fetch_field("Position") ?>">
	        <?PHP
	    }
        $text_out = str_replace('<!--#article_title#-->', $SQL->fetch_field("Title"), $text_out);
        $text_out = str_replace('<!--#radio_selector#-->', '<input type = "radio" name = "input_id" value ="' . $SQL->fetch_field("ID") . '">', $text_out);

        print $text_out;
    }
}

function modify($step)
{
    /* This functions chooses the modify form to output, formats the post and executes the query
     * to update the article.
     * Input:
     *      - Nothing.
     * Output:
     *      - Nothing.(step 0&1)
     *      - Article modified.(step 2)
     * Returns:
     *      - Nothing.
     */

    global $input_id, $input_title, $input_subtitle, $input_category, $input_poster, $input_body, $input_position, $SQL;
    switch($step){
        case 0: // Select the article to modify.
            ?>
            <input type = "hidden" name = "step" value = "1">
            <?PHP
            $query = "SELECT ID, Title FROM ains_articles ORDER BY Position DESC";
            modify_form($query, $step);
            break;
        case 1: // Modify the article.
            ?>
            <input type = "hidden" name = "step" value = "2">
            <input type = "hidden" name = "input_id" value = "<?PHP print $input_id ?>">
            <?PHP
            $query = "SELECT * FROM ains_articles WHERE ID = $input_id";
            modify_form($query, $step);
            break;
        case 2: // Putting the modifications in the database.
            $tmp_date = Date("Y-m-d H:i:s");
            $query  = "REPLACE INTO ains_articles ";
            $query .= "VALUES($input_id, '$input_poster', '$tmp_date', ";
            $query .= "'$input_title', '$input_subtitle', '$input_category', '$input_body', '$input_position')";
            $SQL->db_query($query);
            print("Article modified.");
            break;
    }
}

function modify_form($query, $step)
{
    /* This function outputs the forms for modifying the article.
     * Input:
     *      - $query - The query to use for the form.
     * Output:
     *      - Article selection form.(step 0)
     *      - Modify form.(step 1)
     * Returns:
     *      - Nothing.
     */
    global $in_template, $SQL;
    $SQL->db_query($query);
    $num_results = $SQL->num_results();
    while($SQL->fetch_row()){                       // While there's a new article to be parsed, go on.
        $template_case = 0;
        $current_row = $SQL->Get("current_row");
        if($current_row == 1){                      // If this is the first article. Used for FIRST, LAST etc.
            $template_case = 1;
        }
        if($current_row == $num_results){           // If this is the last article. Used for FIRST, LAST etc.
            $template_case += 2;
        }

        // Parsing the AINS tags.

        $text_out = $in_template;

        if($step == 0){ // Article selection step.
        $text_out = ereg_replace('<!--#FIRST#-->(.*)<!--#/FIRST#-->', ($template_case == 1 || $template_case == 3) ? '\\1' : '', $text_out);
        $text_out = ereg_replace('<!--#NOTFIRST#-->(.*)<!--#\/NOTFIRST#-->', ($template_case == 1 || $template_case == 3) ? '' : '\\1', $text_out);
        $text_out = ereg_replace('<!--#LAST#-->(.*)<!--#/LAST#-->', ($template_case == 2 || $template_case == 3) ? '\\1' : '', $text_out);
        $text_out = ereg_replace('<!--#NOTLAST#-->(.*)<!--#\/NOTLAST#-->', ($template_case == 2 || $template_case == 3) ? '' : '\\1', $text_out);

        $text_out = ereg_replace('<!--#ARTICLES#-->(.*)<!--#/ARTICLES#-->', ($step == 0) ? '\\1' : '', $text_out);
        $text_out = ereg_replace('<!--#MODIFY#-->(.*)<!--#/MODIFY#-->', ($step ==   1) ? '\\1' : '', $text_out);

        $text_out = str_replace('<!--#article_title#-->', $SQL->fetch_field("Title"), $text_out);
        $text_out = str_replace('<!--#radio_selector#-->', '<input type = "radio" name = "input_id" value ="' . $SQL->fetch_field("ID") . '">', $text_out);
        }
        else{ // Modify step.
            ?>
            <input type = "hidden" name = "input_position" value = "<?PHP print $SQL->fetch_field("Position") ?>">
            <?PHP
            $text_out = str_replace('<!--#input_title#-->', '<input type = "text" name = "input_title" size = "25" maxlength = "128" value = "' . $SQL->fetch_field("Title") . '">', $text_out);
            $text_out = str_replace('<!--#input_subtitle#-->', '<input type = "text" name = "input_subtitle" size = "25" maxlength = "255" value = "' . $SQL->fetch_field("Subtitle") . '">', $text_out);
            $text_out = str_replace('<!--#input_category#-->', '<input type = "text" name = "input_category" size = "25" maxlength = "64" value = "' . $SQL->fetch_field("Category") . '">',    $text_out);
            $text_out = str_replace('<!--#input_poster#-->', '<input type = "text" name = "input_poster" size = "25" maxlength = "32" value = "' . $SQL->fetch_field("Poster") . '">', $text_out);
            $text_out = str_replace('<!--#input_body#-->', '<textarea cols = "92" rows = "10" name = "input_body">' . $SQL->fetch_field("Body") . '</textarea>', $text_out);
        }
    print $text_out;
    }
}

function order($step)
{
    /* This functions chooses the order form to output and executes the query
     * to update the article.
     * Input:
     *      - Nothing.
     * Output:
     *      - Nothing.(step 0)
     *      - Article moved.(step 2)
     * Returns:
     *      - Nothing.
     */

    global $input_id, $input_position, $SQL;
    switch($step){
        case 0: // Selecting the article to move and where to move.
            ?>
            <input type = "hidden" name = "step" value = "2">
            <?PHP
            $query = "SELECT ID, Title, Position FROM ains_articles ORDER BY Position DESC";
            order_form($query, $step);
            break;
        case 2: // Moving the article in the database.
            $SQL->db_query("SELECT Position FROM ains_articles WHERE $input_id = ID");
            if ($SQL->fetch_row()){
                $old_position = $SQL->fetch_field("Position");
            }
            else{
                $SQL->error_handler("Article #$input_id does not exist. Moving failed.");
                return false;
            }
            
           if ($old_position == $input_position){
                print("The position did not change.");
                return true;
            }
            
            if ($old_position > $input_position){
                $query = "UPDATE ains_articles SET Position = Position+1 WHERE ";
                $query .= "(Position >= $input_position) && (Position < $old_position)";
            }
            else{
                $query = "UPDATE ains_articles SET Position = Position-1 WHERE ";
                $query .= "(Position > $old_position) && (Position <= $input_position)";
            }
            $SQL->db_query($query);
            
            $query = "UPDATE ains_articles SET Position = $input_position WHERE ID  = $input_id";
            if ($SQL->db_query($query)){
                print("Article moved.");
                return true;
            }
            else{
                error_handler("An error has occurred moving the news items.");
            }
    }
}

function order_form($query, $step)
{
    /* This function outputs the forms for moving the article.
     * Input:
     *      - $query - The query to use for the form.
     * Output:
     *      - Article selection and move form.(step 0)
     * Returns:
     *      - Nothing.
     */

    global $input_id, $in_template, $SQL;
    $SQL->db_query($query);
    $num_results = $SQL->num_results();
    while($SQL->fetch_row()){                       // While there's a new article to be parsed, go on.
        $template_case = 0;
        $current_row = $SQL->Get("current_row");
        if($current_row == 1){                      // If this is the first article. Used for FIRST, LAST etc.
            $template_case = 1;
        }
        if($current_row == $num_results){           // If this is the last article. Used for FIRST, LAST etc.
            $template_case += 2;
        }

        $text_out = $in_template;

        $text_out = ereg_replace('<!--#FIRST#-->(.*)<!--#/FIRST#-->', ($template_case == 1 || $template_case == 3) ? '\\1' : '', $text_out);
        $text_out = ereg_replace('<!--#NOTFIRST#-->(.*)<!--#\/NOTFIRST#-->', ($template_case == 1 || $template_case == 3) ? '' : '\\1', $text_out);
        $text_out = ereg_replace('<!--#LAST#-->(.*)<!--#/LAST#-->', ($template_case == 2 || $template_case == 3) ? '\\1' : '', $text_out);
        $text_out = ereg_replace('<!--#NOTLAST#-->(.*)<!--#\/NOTLAST#-->', ($template_case == 2 || $template_case == 3) ? '' : '\\1', $text_out);

        $text_out = ereg_replace('<!--#ARTICLES#-->(.*)<!--#/ARTICLES#-->', ($step == 0) ? '\\1' : '', $text_out);
        $text_out = ereg_replace('<!--#CONFIRM#-->(.*)<!--#/CONFIRM#-->', ($step == 1) ? '\\1' : '', $text_out);

        $text_out = str_replace('<!--#article_title#-->', $SQL->fetch_field("Title"), $text_out);
        $text_out = str_replace('<!--#radio_selector#-->', '<input type = "radio" name = "input_id" value = "' . $SQL->fetch_field("ID") . '">', $text_out);
        $text_out = str_replace('<!--#radio_moveto#-->', '<input type = "radio" name = "input_position" value   = "' . $SQL->fetch_field("Position") . '">', $text_out);

        print $text_out;
    }
}

function config($step = 0)
{
    global $in_template, $input_news, $input_post, $input_modify, $input_delete, $input_order, $input_config, $SQL;
    
    switch($step){
        case 0:
            ?>
            <input type = "hidden" name = "step" value = "2">
            <?PHP

            $text_out = $in_template;

			$SQL->db_query("SELECT * FROM ains_templates");
			$SQL->fetch_row();
			
            $text_out = str_replace('<!--#input_news#-->', '<input type = "text" name = "input_news" size = "35" maxlength = "128" value = "' . $SQL->fetch_field("newsTemplate") . '">', $text_out);
            $text_out = str_replace('<!--#input_post#-->', '<input type = "text" name = "input_post" size = "35" maxlength = "128" value = "' . $SQL->fetch_field("postTemplate") . '">', $text_out);
            $text_out = str_replace('<!--#input_modify#-->', '<input type = "text" name = "input_modify" size = "35" maxlength = "128" value = "' . $SQL->fetch_field("modifyTemplate") . '">', $text_out);
            $text_out = str_replace('<!--#input_delete#-->', '<input type = "text" name = "input_delete" size = "35" maxlength = "128" value = "' . $SQL->fetch_field("deleteTemplate") . '">', $text_out);
            $text_out = str_replace('<!--#input_order#-->', '<input type = "text" name = "input_order" size = "35" maxlength = "128" value = "' . $SQL->fetch_field("orderTemplate") . '">', $text_out);
            $text_out = str_replace('<!--#input_config#-->', '<input type = "text" name = "input_config" size = "35" maxlength = "128" value = "' . $SQL->fetch_field("configTemplate") . '">', $text_out);

            print $text_out;
            break;

        case 2:
            $query = "REPLACE INTO ains_conf VALUES ('0', $input_news', '$input_post', ";
            $query .= "'$input_modify', '$input_delete', '$input_order', '$input_config')";

            $SQL->db_query($query);
            print("Configuration saved.");
            break;
    }
}

function num_of_articles()
{
    /* This function reads the number of articles from the database and
     * returns this.
     */
    global $SQL;
    $SQL->db_query("SELECT count(*) FROM ains_articles");
    if ($SQL->fetch_row()){
        return $SQL->fetch_field("count(*)");
    }
    else{
        return 0;
    }
}

function first_setup($step)
{
    global $input_user, $input_pass, $input_host, $input_db, $radio_error, $PHP_SELF, $SQL;
    switch($step){
        case 0:
            ?>
			<HTML>
			<HEAD>
			<TITLE>First time setup&config</TITLE>
			</HEAD>
			<BODY>
			<form enctype = "multipart/form-data" action = "<?PHP print $PHP_SELF ?>?action=first_setup" method = "post">
			  <INPUT TYPE = "hidden" NAME = "step" VALUE = "2">
			  <TABLE WIDTH="100%" BORDER="0">
			    <TR>
			      <TD>Database username: </TD>
			      <TD>
			        <INPUT TYPE = "text" NAME = "input_user" SIZE = "25" VALUE = "example">
			      </TD>
			    </TR>
			    <TR>
			      <TD>Database password: </TD>
			      <TD>
			        <INPUT TYPE = "text" NAME = "input_pass" SIZE = "25" VALUE = "example">
			      </TD>
			    </TR>
			    <TR>
			      <TD>Database host name:</TD>
			      <TD> 
			        <INPUT TYPE = "text" NAME = "input_host" SIZE = "25" VALUE = "localhost">
			      </TD>
			    </TR>
			    <TR>
			      <TD>Database name: </TD>
			      <TD>
			        <INPUT TYPE = "text" NAME = "input_db" SIZE = "25" VALUE = "example">
			      </TD>
			    </TR>
			    <TR>
			      <TD>Error Reporting: </TD>
			      <TD>
			        <INPUT TYPE = "radio" NAME = "radio_error" VALUE = "true">
			        Yes 
			        <INPUT TYPE = "radio" NAME = "radio_error" VALUE = "false">
			        No</TD>
			    </TR>
			    <TR>
			      <TD>&nbsp; </TD>
			      <TD>
			        <INPUT TYPE = "submit" NAME = "Submit" VALUE = "Post">
			        <INPUT TYPE = "reset" NAME = "Reset" VALUE = "Reset">
			      </TD>
			    </TR>
			  </TABLE>
			  </form>
			</BODY>
			</HTML>
            <?PHP
            break;
        case 2:
            if (!($config_fp = fopen("../ains_conf.inc.php", 'w'))){
                $SQL->error_handler("Could not create the configuration file.");
            }
            else{
                $config = "<?PHP /*\n$input_user\n$input_pass\n$input_host\n$input_db\n$radio_error\n*/\n?>";
                fwrite($config_fp, $config);
                fclose($config_fp);
                connect();

                $query[] = "CREATE TABLE ains_articles (
                    ID int NOT NULL PRIMARY KEY auto_increment,
                    Poster varchar(32) NOT NULL,
                    PostDate datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
                    Title varchar(128) NOT NULL,
                    Subtitle varchar(255) NOT NULL,
                    Category varchar(64) NOT NULL,
                    Body blob NOT NULL,
                    Position int NOT NULL)";

                $query[] = "CREATE TABLE ains_templates (
                    newsTemplate varchar(128) NOT NULL,
                    postTemplate varchar(128) NOT NULL,
                    deleteTemplate varchar(128) DEFAULT '../templates/delete_template.htm' NOT NULL,
                    modifyTemplate varchar(128) DEFAULT '../templates/modify_template.htm' NOT NULL,
                    orderTemplate varchar(128) DEFAULT '../templates/order_template.htm' NOT NULL,
                    configTemplate varchar(128) DEFAULT '../templates/config_template.htm' NOT NULL)";

                $query[] = "INSERT INTO ains_templates VALUES ('/templates/news_template.htm', '/templates/post_template.htm',
                            '/templates/delete_template.htm', '/templates/modify_template.htm', '/templates/order_template.htm',
                            '/templates/config_template.htm')";

                while ($each_query = each($query))
                {
                    $SQL->db_query($each_query[1]);
                }

                ?>
                <HTML>
                <HEAD>
                <TITLE>Creating tables...</TITLE>
                </HEAD>
                <BODY>
                <STYLE>
                .header {
                    font-family: Arial, Helvetica, sans-serif;
                    font-size: 20px;
                    font-weight: bold;
                }
                </STYLE>
                <TABLE WIDTH = "100%" HEIGHT = "95%" BGCOLOR = "black" cellpadding ="1" cellspacing = "2">
                    <TR>
                        <TD bgcolor = "#33AACC" class = "header" align = "center">
                        Config file and database created.
                        </TD>
                    </TR>
                </TABLE>
                </BODY>
                </HTML>
                <?PHP
            }
            break;
    }
}