<?PHP
/*
AINS - Ad Fundum Integrated News Script
Copyright (C) 2001 Johannes Gijsbers

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

For the complete GNU General Public License, read the file LICENSE.

************************
Filename: ains_main.php
Version: 0.02b
Written by: Taradino(Taradino@Softhome.net)
Description: Main outputting file for AINS
History:
(for details, take a look at CHANGELOG in the documentation dir)
[11-03-2001] 0.00  	- Development starts.
[13-03-2001] 0.01a 	- Output functions completed
				   	- Comments in code.
[08-04-2001] 0.02b  - Prepared this file for reading the easier setup file.
				    - Added ability to output one article by specifying just one.
				    - Changed from OOP to normal functions.
				    - Absolute paths.

Goals(Sorted by priority):
- Testing on stability and errors.
************************
*/

include("$ains_path/ains_global.inc");

function print_articles($start_position="", $end_position="", $start_date="", $end_date="", $sort="", $num_articles="", $one_position="")
{
	/* This functions takes care of printing the articles in the database you connected
	 * to with ains_news().
	 * Input:
	 *		- $start_position - This limits the articles to the position higher than $start_position.
	 *		- $end_position - This limits the articles to the position lower than $end_position.
	 *		- $start_date - This limits the articles to the dates later than $start_date.
	 *		- $end_date - This limits the articles to the dates earlier than $end_date.
	 *		- $sort - Sort the articles by any row in ains_articles, for example:
	 *						- PostDate
	 *						- Poster
	 *						- Title
	 *						- Category
	 *                 		- If you specify no sort, Position will be used.
	 *		- $num_artles - This limits the articles to the value of $num_articles.
	 * Output:
	 *		- The articles.(Doh!)
	 *		- Error message - If db_query() or fetch_row() in the SQL class don't succeed or if the
	 *						  config file could not be opened.
	 * Returns:
	 *		- Nothing
	 */

	global $ains_path, $in_template, $SQL;
	if(!connect()){
		$SQL->error_handler("The configuration file could not be opened.");
		die();
	}
	fetch_template("news");
	// Constructing the query.
	$query = "SELECT * FROM ains_articles";
	if($start_position || $start_date || $end_position || $end_position || $one_position){
		$query .= " WHERE ((position >= $start_position) && (position <= $end_position) && (PostDate >= $start_Date)";
		$query .= " && (PostDate <= $end_date) && (position == $one_position))";
	}

	if($sort){
		$query .= " ORDER BY $sort DESC";
	}
	else{
		$query .= " ORDER BY Position DESC";
	}

	if($num_articles){
		$query .= " LIMIT $num_articles";
	}
	// End constructing the query.

	$SQL->db_query($query);
	$num_results = $SQL->num_results();
	while($SQL->fetch_row()){ 						// While there's a new article to be parsed, go on.
		$template_case = 0;
		$current_row = $SQL->Get("current_row");
		if($current_row == 1){ 						// If this is the first article. Used for FIRST, LAST etc.
			$template_case = 1;
		}
		if($current_row == $num_results){			// If this is the last article. Used for FIRST, LAST etc.
			$template_case += 2;
		}

		// Parsing all the AINS tags.

		$text_out = $in_template;

		$text_out = ereg_replace('<!--#FIRST#-->(.*)<!--#\/FIRST#-->', ($template_case == 1 || $template_case == 3) ? '\\1' : '', $text_out);
		$text_out = ereg_replace('<!--#NOTFIRST#-->(.*)<!--#\/NOTFIRST#-->', ($template_case == 1 || $template_case == 3) ? '' : '\\1', $text_out);
		$text_out = ereg_replace('<!--#LAST#-->(.*)<!--#\/LAST#-->', ($template_case == 2 || $template_case == 3) ? '\\1' : '', $text_out);
		$text_out = ereg_replace('<!--#NOTLAST#-->(.*)<!--#\/NOTLAST#-->', ($template_case == 2 || $template_case == 3) ? '' : '\\1', $text_out);

		$text_out = str_replace('<!--#article_title#-->', $SQL->fetch_field("Title"), $text_out);
		$text_out = str_replace('<!--#article_subtitle#-->', $SQL->fetch_field("Subtitle"), $text_out);
		$text_out = str_replace('<!--#article_datetime#-->', $SQL->fetch_field("PostDate"), $text_out);
		$text_out = str_replace('<!--#article_category#-->', $SQL->fetch_field("Category"), $text_out);
		$text_out = str_replace('<!--#article_id#-->', $SQL->fetch_field("ID"), $text_out);
		$text_out = str_replace('<!--#article_poster#-->', $SQL->fetch_field("Poster"), $text_out);
		$text_out = str_replace('<!--#article_body#-->', nl2br($SQL->fetch_field("Body")), $text_out);
		$text_out = str_replace('<!--#article_position#-->', $SQL->fetch_field("Position"), $text_out);
		$text_out = str_replace('<!--#num_of_articles#-->', $SQL->num_results(), $text_out);
		
		$text_out = ereg_replace('<!--#IF_article_title#-->(.*)<!--#END_title#-->' , $SQL->fetch_field("Title") != '' ? '\\1' : '' , $text_out);
		$text_out = ereg_replace('<!--#IF_article_subtitle#-->(.*)<!--#END_subtitle#-->' , $SQL->fetch_field("Subtitle") != '' ? '\\1' : '' , $text_out);
		$text_out = ereg_replace('<!--#IF_article_category#-->(.*)<!--#END_category#-->' , $SQL->fetch_field("Category") != '' ? '\\1' : '' , $text_out);
		$text_out = ereg_replace('<!--#IF_article_poster#-->(.*)<!--#END_poster#-->' , $SQL->fetch_field("Poster") != '' ? '\\1' : '' , $text_out);
		$text_out = ereg_replace('<!--#IF_article_body#-->(.*)<!--#END_body#-->' , $SQL->fetch_field("Body") != '' ? '\\1' : '' , $text_out);

		print $text_out;
	}
}