<?PHP
/*
AINS - Ad Fundum Integrated News Script
Copyright (C) 2001 Johannes Gijsbers

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

For the complete GNU General Public License, read the file LICENSE.

************************
Filename: ains_mysql.inc
Version: 0.02b
Written by: Taradino(Taradino@Softhome.net)
Description: mySQL abstraction layer for use with AINS
History:
[09-03-2001] 0.00  - Development starts.
[12-03-2001] 0.01a - mySQL layer completed.
				   - Connection error checking completed.
				   - Comments in code completed.
[11-04-2001] 0.02b - Added code that resets values when running a new query.
				   - Added code that also checks if a database has been selected.

Goals(Sorted by priority):
- Testing on stability and errors.
************************
*/

class ains_sql
{
	var $db_user;					// Username for logging into database.
	var $db_password;				// Password for logging into database.
	var $db_host;					// Host name of database.
	var $db_name;					// Database used for AINS

	var $error_reporting = true;	// Boolean to set error reporting or to be in quiet mode. Default = true.

	var $connect_id 	 = false;	// Current connection ID.
	var $result_id  	 = false;	// Current query result.

	var $host_connected  = false;	// Boolean set when connected to database host.
	var $db_selected     = false;	// Boolean set when a database is selected.
	var $results    	 = false;	// Boolean set when a query has results(even if it is 0).
	var $row_loaded 	 = false;	// Boolean set when results have been loaded into $fields_active_row.

	var $num_of_rows;				// Number of results from a query.
	var $current_row;				// Holds the current row of total rows returned.
	var $fields_active_row;			// Array that holds the fields in $current_row.

	function error_handler($error_message = "")
	{
		/* This functions handles all errors.
		 * Input:
		 * 		- None.
		 * 		- User defined error message.
		 * Output:
		 * 		- User defined error message.
		 * 		- mySQL error.
		 * Returns:
		 * 		- None.
		 */
	
		if($this->error_reporting){
			if($error_message){
				print "<b>AINS Error:</b> $error_message<br>";
			}
			else{
				print "<b>SQl Error:</b> " . mysql_error() . "<br>";
			}
		}
	}
	
	function set($variable, $setting)
	{
		// This functions sets any of the variables in this class.
		$this->$variable = $setting;
	}

	function get($variable)
	{
		// This functions gets any of the variables in this class.
		return $this->$variable;
	}

	function host_connect()
	{
		/* This function connects to the database engine defined with $db_host using
		 * $db_user and $db_password.
		 * Input:
		 * 		- None.
		 * Output:
		 * 		- None - If host connection succeeds.
		 * 		- Error message - If host connection fails and $error_reporting is true.
		 * Returns:
		 * 		- True - If host connection succeeds.
		 *		- False - If host connection fails.
		 */

		$this->connect_id = mysql_connect($this->db_host, $this->db_user, $this->db_password);
		if($this->connect_id){
			$this->host_connected = true;
			return true;
		}
		else{
			$this->error_handler();
			return false;
		}
	}

	function db_connect()
	{
		/* This function selects the database $db_name located on the connection $connect_id.
		 * Input:
		 *		- None.
		 * Output:
		 * 		- None - If database selection succeeds.
		 *		- Error message - If database selection fails and $error_reporting = true.
		 * Returns:
		 * 		- True - If database selection succeeds.
		 *		- False - If database selection fails.
		 */

		if($this->host_connected){
			if(mysql_select_db($this->db_name, $this->connect_id)){
				$this->db_selected = true;
				return true;
			}
			else{
				$this->error_handler();
				return false;
			}
		}
		else{
			$this->error_handler("No connection to a database host has been made.");
			return false;
		}
	}

	function db_close()
	{
		/* This function closes the current connection to the database engine and
		 * clears all variables set in the functions in this file.
		 * Input:
		 *		- None.
		 * Output:
		 *		- None.
		 *		- Error message - If no connection had been made yet and $error_reporting = true.
		 * Returns:
		 *		- True - If there already was a connection.
		 *		- False - If no connection had been made yet.
		 */

		if($this->host_connected){
			mysql_close($this->connect_id);
			$this->connect_id = false;
			$this->result_id = false;
			$this->host_connected = false;
			$this->db_selected = false;
			$this->results = false;
			$this->row_loaded = false;
			$this->num_of_rows = 0;
			$this->current_row = 0;
			$this->fields_active_row = false;
			return true;
		}
		else{
			$this->error_handler("No connection has been made yet, so no connection could be closed");
			return false;
		}
	}

	function db_query($in_query)
	{
		/* This functions runs the query $in_query in the
		 * database $db_name on the host $connection_id.
		 * Input:
		 *		- $in_query.
		 * Output:
		 *		- None.
		 *		- Error message - If query fails to complete and $error_reporting = true.
		 * Returns:
		 *		- True - If query succeeds.
		 * (This does NOT mean that the query returns any results, it just means the query was valid.)
		 *		- False - If query fails.
		 */
		$this->results = false;
		$this->row_loaded = false;
		$this->num_of_rows = 0;
		$this->current_row = 0;
		$this->fields_active_row = false;
		
		if($this->host_connected AND $this->db_selected AND isset($in_query)){
			$this->result_id = mysql_query($in_query, $this->connect_id);
			if($this->result_id){
				$this->results = true;
				return true;
			}
			else{
				$this->results = false;
				$this->error_handler();
				return false;
			}
		}
		else{
			$message = "";
			if(!$this->host_connected){
				$message .= "No connection to a database host has been made.\n";
			}
			elseif(!$this->db_selected){
				$message .= "No database has been selected.\n";
			}
			else{
				$message = "No query has been set.";
			}
			$this->results = false;
			$this->error_handler($message);
			return false;
		}
	}

	function num_results()
	{
		/* This function reads the number of rows from $result_id.
		 * Input:
		 *		- None.
		 * Output:
		 *		- None.
		 *		- Error message - If no query has been made yet and $error_reporting = true.
		 * Returns:
		 *		- The number of rows in $result_id.
		 *		- False - If no query has been made yet.
		 */

		if($this->results){
			$this->num_of_rows = mysql_num_rows($this->result_id);
			return $this->num_of_rows;
		}
		else{
			$this->error_handler("No query has been made yet.");
			return false;
		}
	}

	function fetch_row()
	{
		/* This functions loads the fields in current_row into the array $fields_active_row.
		 * Input:
		 *		- None.
		 * Output:
		 *		- None.
		 *		- Error message - If no fields could be loaded and $error_reporting = true.
		 * Returns:
		 *		- True - If fields are loaded into $fields_active_row.
		 *		- False - If no fields could be loaded.
		 */

		if($this->host_connected AND $this->db_selected AND $this->results){
			if($this->current_row <= $this->num_of_rows){
				$this->fields_active_row = mysql_fetch_array($this->result_id);
				if($this->fields_active_row){
					$this->row_loaded = true;
					$this->current_row++;
					return true;
				}
				else{
					return false;
				}
			}
			else{
				return false;
			}
		}
		else{
			$message = "";
			if(!$this->host_connected){
				$message .= "No connection to a database host has been made.\n";
			}
			elseif($this->db_selected){
				$message .= "No database has been selected.\n";
			}
			else{
				$message .= "No results were returned from your query.";
			}
			$this->error_handler($message);
			return false;
		}
	}

	function fetch_field($field_name = "")
	{
		/* This function reads a field from $fields_active_row and returns it.
		 * Input:
		 *		- $field_name.
		 * Output:
		 *		- None.
		 *		- Error message - If the fetching doesn't succeed and $error_reporting = true.
		 * Returns:
		 *		- $fields_active_row[$field_name]
		 *		- False - If the fetching doesn't succeed.
		 */

		if($this->row_loaded AND $field_name != ""){
			return $this->fields_active_row[$field_name];
		}
		else{
			$message = "";
			if(!$this->row_loaded){
				$message = "No fields have been loaded into the active row.\n";
			}
			if($field_name = ""){
				$message .= "No field name was set to fetch from $fields_active_row.";
			}
			$this->error_handler($message);
			return false;
		}
	}
}